@@ -23,6 +23,7 @@ from .literals import (
     PolicyTypeType,
     ResourceTypeType,
     TypeType,
+    ValidatePolicyResourceTypeType,
 )
 from .paginator import (
     ListAccessPreviewFindingsPaginator,
@@ -91,7 +92,7 @@ class Exceptions:
 
 class AccessAnalyzerClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html)
     """
 
@@ -110,7 +111,7 @@ class AccessAnalyzerClient(BaseClient):
         Retroactively applies the archive rule to existing findings that meet the
         archive rule criteria.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.apply_archive_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.apply_archive_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#apply_archive_rule)
         """
 
@@ -118,7 +119,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#can_paginate)
         """
 
@@ -126,7 +127,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Cancels the requested policy generation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.cancel_policy_generation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.cancel_policy_generation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#cancel_policy_generation)
         """
 
@@ -141,7 +142,7 @@ class AccessAnalyzerClient(BaseClient):
         Creates an access preview that allows you to preview IAM Access Analyzer
         findings for your resource before deploying resource permissions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_access_preview)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_access_preview)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#create_access_preview)
         """
 
@@ -157,7 +158,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Creates an analyzer for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_analyzer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_analyzer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#create_analyzer)
         """
 
@@ -172,7 +173,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Creates an archive rule for the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_archive_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_archive_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#create_archive_rule)
         """
 
@@ -180,7 +181,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Deletes the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_analyzer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_analyzer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#delete_analyzer)
         """
 
@@ -190,7 +191,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Deletes the specified archive rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_archive_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_archive_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#delete_archive_rule)
         """
 
@@ -204,7 +205,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#generate_presigned_url)
         """
 
@@ -214,7 +215,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves information about an access preview for the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_access_preview)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_access_preview)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_access_preview)
         """
 
@@ -224,7 +225,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves information about a resource that was analyzed.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzed_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzed_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_analyzed_resource)
         """
 
@@ -232,7 +233,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves information about the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_analyzer)
         """
 
@@ -242,7 +243,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves information about an archive rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_archive_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_archive_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_archive_rule)
         """
 
@@ -250,7 +251,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves information about the specified finding.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_finding)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_finding)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_finding)
         """
 
@@ -264,7 +265,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves the policy that was generated using `StartPolicyGeneration` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_generated_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_generated_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#get_generated_policy)
         """
 
@@ -281,7 +282,7 @@ class AccessAnalyzerClient(BaseClient):
         Retrieves a list of access preview findings generated by the specified access
         preview.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_preview_findings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_preview_findings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_access_preview_findings)
         """
 
@@ -291,7 +292,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves a list of access previews for the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_previews)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_previews)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_access_previews)
         """
 
@@ -307,7 +308,7 @@ class AccessAnalyzerClient(BaseClient):
         Retrieves a list of resources of the specified type that have been analyzed by
         the specified analyzer..
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzed_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzed_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_analyzed_resources)
         """
 
@@ -317,7 +318,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves a list of analyzers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_analyzers)
         """
 
@@ -327,7 +328,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves a list of archive rules created for the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_archive_rules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_archive_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_archive_rules)
         """
 
@@ -343,7 +344,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves a list of findings generated by the specified analyzer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_findings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_findings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_findings)
         """
 
@@ -353,7 +354,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Lists all of the policy generations requested in the last seven days.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_policy_generations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_policy_generations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_policy_generations)
         """
 
@@ -361,7 +362,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Retrieves a list of tags applied to the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#list_tags_for_resource)
         """
 
@@ -375,7 +376,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Starts the policy generation request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_policy_generation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_policy_generation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#start_policy_generation)
         """
 
@@ -383,7 +384,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Immediately starts a scan of the policies applied to the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_resource_scan)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_resource_scan)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#start_resource_scan)
         """
 
@@ -391,7 +392,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Adds a tag to the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#tag_resource)
         """
 
@@ -399,7 +400,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Removes a tag from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#untag_resource)
         """
 
@@ -414,7 +415,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Updates the criteria and values for the specified archive rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_archive_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_archive_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#update_archive_rule)
         """
 
@@ -430,7 +431,7 @@ class AccessAnalyzerClient(BaseClient):
         """
         Updates the status for the specified findings.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_findings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_findings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#update_findings)
         """
 
@@ -441,12 +442,13 @@ class AccessAnalyzerClient(BaseClient):
         policyType: PolicyTypeType,
         locale: LocaleType = ...,
         maxResults: int = ...,
-        nextToken: str = ...
+        nextToken: str = ...,
+        validatePolicyResourceType: ValidatePolicyResourceTypeType = ...
     ) -> ValidatePolicyResponseTypeDef:
         """
         Requests the validation of a policy and returns a list of findings.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Client.validate_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Client.validate_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/client.html#validate_policy)
         """
 
@@ -455,7 +457,7 @@ class AccessAnalyzerClient(BaseClient):
         self, operation_name: Literal["list_access_preview_findings"]
     ) -> ListAccessPreviewFindingsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listaccesspreviewfindingspaginator)
         """
 
@@ -464,7 +466,7 @@ class AccessAnalyzerClient(BaseClient):
         self, operation_name: Literal["list_access_previews"]
     ) -> ListAccessPreviewsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listaccesspreviewspaginator)
         """
 
@@ -473,14 +475,14 @@ class AccessAnalyzerClient(BaseClient):
         self, operation_name: Literal["list_analyzed_resources"]
     ) -> ListAnalyzedResourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listanalyzedresourcespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_analyzers"]) -> ListAnalyzersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listanalyzerspaginator)
         """
 
@@ -489,14 +491,14 @@ class AccessAnalyzerClient(BaseClient):
         self, operation_name: Literal["list_archive_rules"]
     ) -> ListArchiveRulesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listarchiverulespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_findings"]) -> ListFindingsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listfindingspaginator)
         """
 
@@ -505,13 +507,13 @@ class AccessAnalyzerClient(BaseClient):
         self, operation_name: Literal["list_policy_generations"]
     ) -> ListPolicyGenerationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listpolicygenerationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["validate_policy"]) -> ValidatePolicyPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#validatepolicypaginator)
         """
